@@ -41,6 +41,8 @@ from .dom import (
     isNormative,
     isOddNode,
     moveContents,
+    nextSiblingElement,
+    nextSiblingNode,
     nodeIter,
     outerHTML,
     parentElement,
@@ -56,6 +58,7 @@ from .dom import (
     replaceContents,
     replaceMacros,
     replaceNode,
+    replaceWithContents,
     safeID,
     scopingElements,
     sectionName,
