@@ -9,25 +9,28 @@ from lxml.html import tostring
 
 from .. import t
 from ..DefaultOrderedDict import DefaultOrderedDict
-from ..messages import *
+from ..messages import die, warn
+
+T = t.TypeVar("T")
+ElementType = t.Union[etree.ElementBase]
 
 
-def flatten(arr):
+def flatten(arr: t.Iterable) -> t.Iterator:
     for el in arr:
-        if isinstance(el, collections.abc.Iterable) and not isinstance(el, str) and not lxml.etree.iselement(el):
+        if isinstance(el, collections.abc.Iterable) and not isinstance(el, str) and not etree.iselement(el):
             yield from flatten(el)
         else:
             yield el
 
 
-def unescape(string):
+def unescape(string: str) -> str:
     import html
 
     return html.unescape(string)
 
 
-def findAll(sel, context):
-    if isinstance(context, constants.specClass):
+def findAll(sel: str, context: t.Union["t.SpecType", ElementType]) -> t.List[ElementType]:
+    if hasattr(context, "document"):
         context = context.document
     try:
         return CSSSelector(sel, namespaces={"svg": "http://www.w3.org/2000/svg"})(context)
@@ -36,7 +39,7 @@ def findAll(sel, context):
         return []
 
 
-def find(sel, context=None):
+def find(sel: str, context=None) -> ElementType:
     result = findAll(sel, context)
     if result:
         return result[0]
@@ -44,7 +47,7 @@ def find(sel, context=None):
         return None
 
 
-def escapeCSSIdent(val):
+def escapeCSSIdent(val: str) -> str:
     if len(val) == 0:
         die("Programming error: can't escape an empty ident.")
         return ""
@@ -60,7 +63,7 @@ def escapeCSSIdent(val):
             or (i == 0 and 0x30 <= code <= 0x39)
             or (i == 1 and 0x30 <= code <= 0x39 and firstCode == 0x2D)
         ):
-            ident += fr"\{code:x} "
+            ident += rf"\{code:x} "
         elif (
             code >= 0x80
             or code == 0x2D
@@ -75,7 +78,7 @@ def escapeCSSIdent(val):
     return ident
 
 
-def escapeUrlFrag(val):
+def escapeUrlFrag(val: str) -> str:
     result = ""
     for char in val:
         if validUrlUnit(char):
@@ -86,7 +89,7 @@ def escapeUrlFrag(val):
     return result
 
 
-def validUrlUnit(char):
+def validUrlUnit(char: str) -> bool:
     c = ord(char)
     if c < 0xA0:
         # ASCII range
@@ -112,7 +115,7 @@ def validUrlUnit(char):
         return True
 
 
-def textContent(el, exact=False):
+def textContent(el: ElementType, exact: bool = False) -> str:
     # If exact is False, then any elements with data-deco attribute
     # get ignored in the textContent.
     # This allows me to ignore things added by Bikeshed by default.
@@ -124,7 +127,7 @@ def textContent(el, exact=False):
         return textContentIgnoringDecorative(el)
 
 
-def textContentIgnoringDecorative(el):
+def textContentIgnoringDecorative(el: ElementType) -> str:
     str = el.text or ""
     for child in childElements(el):
         if child.get("data-deco") is None:
@@ -133,13 +136,13 @@ def textContentIgnoringDecorative(el):
     return str
 
 
-def innerHTML(el):
+def innerHTML(el: t.Optional[ElementType]) -> str:
     if el is None:
         return ""
     return (el.text or "") + "".join(tostring(x, encoding="unicode") for x in el)
 
 
-def outerHTML(el, literal=False, with_tail=False):
+def outerHTML(el: t.Optional[ElementType], literal: bool = False, with_tail: bool = False) -> str:
     if el is None:
         return ""
     if isinstance(el, str):
@@ -151,7 +154,7 @@ def outerHTML(el, literal=False, with_tail=False):
     return tostring(el, with_tail=with_tail, encoding="unicode")
 
 
-def serializeTag(el):
+def serializeTag(el: ElementType) -> str:
     # Serialize *just* the opening tag for the element.
     # Use when you want to output the HTML,
     # but it might be a container with a lot of content.
@@ -162,11 +165,11 @@ def serializeTag(el):
     return tag
 
 
-def foldWhitespace(text):
+def foldWhitespace(text: str) -> str:
     return re.sub(r"(\s|\xa0)+", " ", text)
 
 
-def parseHTML(text):
+def parseHTML(text: str) -> t.List[ElementType]:
     doc = html5lib.parse(text, treebuilder="lxml", namespaceHTMLElements=False)
     head = doc.getroot()[0]
     body = doc.getroot()[1]
@@ -184,7 +187,7 @@ def parseHTML(text):
         return []
 
 
-def parseDocument(text):
+def parseDocument(text: str):
     doc = html5lib.parse(text, treebuilder="lxml", namespaceHTMLElements=False)
     return doc
 
@@ -208,6 +211,19 @@ def parentElement(el):
     return el.getparent()
 
 
+def nextSiblingNode(el):
+    return el.getnext()
+
+
+def nextSiblingElement(el):
+    while True:
+        next = nextSiblingNode(el)
+        if next is None:
+            return None
+        if isElement(next):
+            return next
+
+
 def appendChild(parent, *children):
     # Appends either text or an element.
     children = list(flatten(children))
@@ -251,7 +267,7 @@ def insertBefore(target, *els):
     parent = target.getparent()
     index = parent.index(target)
     prevSibling = parent[index - 1] if index > 0 else None
-    for el in els:
+    for el in flatten(els):
         if isinstance(el, str):
             if prevSibling is not None:
                 prevSibling.tail = (prevSibling.tail or "") + el
@@ -266,7 +282,7 @@ def insertBefore(target, *els):
 
 def insertAfter(target, *els):
     parent = target.getparent()
-    for el in els:
+    for el in flatten(els):
         if isinstance(el, str):
             target.tail = (target.tail or "") + el
         else:
@@ -311,6 +327,10 @@ def replaceContents(el, newElements):
     return appendContents(el, newElements)
 
 
+def replaceWithContents(el):
+    return replaceNode(el, childNodes(el, clear=True))
+
+
 def moveContents(toEl, fromEl):
     replaceContents(toEl, fromEl)
     fromEl.text = ""
@@ -554,7 +574,7 @@ _classMap: t.Dict[t.Tuple[str, str], bool]
 _classMap = {}
 
 
-def hasClass(el, cls: str, classMap=_classMap):
+def hasClass(el, cls: str, classMap=_classMap):  # pylint: disable=dangerous-default-value
     elClass = el.get("class")
     if elClass is None:
         return False
@@ -869,7 +889,9 @@ def nextIter(it, default=None):
         return default
 
 
-def createElement(tag, attrs={}, *children):
+def createElement(tag, attrs=None, *children):
+    if attrs is None:
+        attrs = {}
     el = etree.Element(tag, {n: v for n, v in attrs.items() if v is not None})
     for child in children:
         appendChild(el, child)
