@@ -1,10 +1,7 @@
 import functools
 import re
-from itertools import *
 
-from .. import Line
-from ..h import escapeAttr
-from ..messages import *
+from .. import Line, messages as m, h
 
 
 def parse(
@@ -149,7 +146,7 @@ def tokenizeLines(
             if infoString:
                 # For now, I only care about lang
                 lang = infoString.split(" ")[0]
-                classAttr = " class='language-{}'".format(escapeAttr(lang))
+                classAttr = f" class='language-{h.escapeAttr(lang)}'"
             else:
                 classAttr = ""
             line.text = f"{ws}<xmp{classAttr}>"
@@ -161,7 +158,7 @@ def tokenizeLines(
                 }
             )
             continue
-        match = re.match(fr"\s*<({rawElements})[ >]", line.text)
+        match = re.match(rf"\s*<({rawElements})[ >]", line.text)
         if match:
             tokens.append(
                 {
@@ -252,8 +249,11 @@ def tokenizeLines(
         token["line"] = line
         tokens.append(token)
 
-    # for token in tokens:
-    #    print(f"{' ' * (11 - len(token['type']))}{token['type']}: {token['line'].text.rstrip()}")
+    if False:  # pylint: disable=using-constant-test
+        for i, token in enumerate(tokens):
+            print(
+                f"{' '*(2-len(str(i)))}{i} {' ' * (11 - len(token['type']))}{token['type']}: {token['line'].text.rstrip()}"
+            )
 
     return tokens
 
@@ -343,7 +343,7 @@ def stripPrefix(token, numSpacesForIndentation, len):
         elif text[offset : offset + numSpacesForIndentation] == " " * numSpacesForIndentation:
             offset += numSpacesForIndentation
         else:
-            die(
+            m.die(
                 f'Line {token["line"].i} isn\'t indented enough (needs {len} indent{"" if len == 1 else "s"}) to be valid Markdown:\n"{text[:-1]}"'
             )
     return text[offset:]
@@ -364,11 +364,20 @@ def stripCommonWsPrefix(tokens):
     prefix = functools.reduce(commonPrefix, ws)
     prefixLen = len(prefix)
     for token in tokens:
-        token["line"].text = token["line"].text[prefixLen:]
+        stripped = token["line"].text
+        if len(token["line"].text) > prefixLen:
+            # Don't remove from blank lines,
+            # or else you'll eat the newline!
+            stripped = token["line"].text[prefixLen:]
+        token["line"].text = stripped
     return tokens
 
 
 def commonPrefix(line1, line2):
+    if line1 is None:
+        return line2
+    if line2 is None:
+        return line1
     prefixSoFar = ""
     for i, char in enumerate(line1):
         if i == len(line2):
@@ -381,6 +390,8 @@ def commonPrefix(line1, line2):
 
 
 def getWsPrefix(line):
+    if line.strip() == "":
+        return None
     return re.match(r"(\s*)", line).group(1)
 
 
@@ -475,7 +486,7 @@ def parseMultiLineHeading(stream):
     elif stream.nexttype() == "dash-line":
         level = 3
     else:
-        die(
+        m.die(
             "Markdown parser error: tried to parse a multiline heading from:\n"
             + stream.prevraw()
             + stream.currraw()
@@ -739,14 +750,20 @@ class TokenStream:
         self,
         tokens,
         numSpacesForIndentation,
-        before={"type": "blank", "prefixlen": 0},
-        after={"type": "eof", "prefixlen": 0},
+        before=None,
+        after=None,
     ):
         self.tokens = tokens
         self.i = 0
         self.numSpacesForIndentation = numSpacesForIndentation
-        self.before = before
-        self.after = after
+        if before is None:
+            self.before = {"type": "blank", "prefixlen": 0}
+        else:
+            self.before = before
+        if after is None:
+            self.after = {"type": "eof", "prefixlen": 0}
+        else:
+            self.after = after
 
     def __len__(self):
         return len(self.tokens)
